==> knative-model-6.4.1-sources.jar: io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabSourceFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitLabSourceFluentImpl<A extends GitLabSourceFluent<A>> extends BaseFluent<A> implements GitLabSourceFluent<A>{
  public GitLabSourceFluentImpl() {
  }
  public GitLabSourceFluentImpl(GitLabSource instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private GitLabSourceSpecBuilder spec;
  private GitLabSourceStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public GitLabSourceFluent.MetadataNested<A> withNewMetadata() {
    return new GitLabSourceFluentImpl.MetadataNestedImpl();
  }
  public GitLabSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new GitLabSourceFluentImpl.MetadataNestedImpl(item);
  }
  public GitLabSourceFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public GitLabSourceFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public GitLabSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitLabSourceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public GitLabSourceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(GitLabSourceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new GitLabSourceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public GitLabSourceFluent.SpecNested<A> withNewSpec() {
    return new GitLabSourceFluentImpl.SpecNestedImpl();
  }
  public GitLabSourceFluent.SpecNested<A> withNewSpecLike(GitLabSourceSpec item) {
    return new GitLabSourceFluentImpl.SpecNestedImpl(item);
  }
  public GitLabSourceFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public GitLabSourceFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new GitLabSourceSpecBuilder().build());
  }
  public GitLabSourceFluent.SpecNested<A> editOrNewSpecLike(GitLabSourceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitLabSourceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public GitLabSourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(GitLabSourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new GitLabSourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public GitLabSourceFluent.StatusNested<A> withNewStatus() {
    return new GitLabSourceFluentImpl.StatusNestedImpl();
  }
  public GitLabSourceFluent.StatusNested<A> withNewStatusLike(GitLabSourceStatus item) {
    return new GitLabSourceFluentImpl.StatusNestedImpl(item);
  }
  public GitLabSourceFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public GitLabSourceFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new GitLabSourceStatusBuilder().build());
  }
  public GitLabSourceFluent.StatusNested<A> editOrNewStatusLike(GitLabSourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GitLabSourceFluentImpl that = (GitLabSourceFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<GitLabSourceFluent.MetadataNested<N>> implements GitLabSourceFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) GitLabSourceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends GitLabSourceSpecFluentImpl<GitLabSourceFluent.SpecNested<N>> implements GitLabSourceFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(GitLabSourceSpec item) {
      this.builder = new GitLabSourceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new GitLabSourceSpecBuilder(this);
    }
    GitLabSourceSpecBuilder builder;
    public N and() {
      return (N) GitLabSourceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends GitLabSourceStatusFluentImpl<GitLabSourceFluent.StatusNested<N>> implements GitLabSourceFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(GitLabSourceStatus item) {
      this.builder = new GitLabSourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new GitLabSourceStatusBuilder(this);
    }
    GitLabSourceStatusBuilder builder;
    public N and() {
      return (N) GitLabSourceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabSourceFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitLabSourceFluentImpl<A extends GitLabSourceFluent<A>> extends BaseFluent<A> implements GitLabSourceFluent<A>{
  public GitLabSourceFluentImpl() {
  }
  public GitLabSourceFluentImpl(GitLabSource instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private GitLabSourceSpecBuilder spec;
  private GitLabSourceStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public GitLabSourceFluentImpl.MetadataNested<A> withNewMetadata() {
    return new GitLabSourceFluentImpl.MetadataNestedImpl();
  }
  public GitLabSourceFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new GitLabSourceFluentImpl.MetadataNestedImpl(item);
  }
  public GitLabSourceFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public GitLabSourceFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public GitLabSourceFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitLabSourceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public GitLabSourceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(GitLabSourceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new GitLabSourceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public GitLabSourceFluentImpl.SpecNested<A> withNewSpec() {
    return new GitLabSourceFluentImpl.SpecNestedImpl();
  }
  public GitLabSourceFluentImpl.SpecNested<A> withNewSpecLike(GitLabSourceSpec item) {
    return new GitLabSourceFluentImpl.SpecNestedImpl(item);
  }
  public GitLabSourceFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public GitLabSourceFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new GitLabSourceSpecBuilder().build());
  }
  public GitLabSourceFluentImpl.SpecNested<A> editOrNewSpecLike(GitLabSourceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitLabSourceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public GitLabSourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(GitLabSourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new GitLabSourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public GitLabSourceFluentImpl.StatusNested<A> withNewStatus() {
    return new GitLabSourceFluentImpl.StatusNestedImpl();
  }
  public GitLabSourceFluentImpl.StatusNested<A> withNewStatusLike(GitLabSourceStatus item) {
    return new GitLabSourceFluentImpl.StatusNestedImpl(item);
  }
  public GitLabSourceFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public GitLabSourceFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new GitLabSourceStatusBuilder().build());
  }
  public GitLabSourceFluentImpl.StatusNested<A> editOrNewStatusLike(GitLabSourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitLabSourceFluentImpl that = (GitLabSourceFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<GitLabSourceFluentImpl.MetadataNested<N>> implements GitLabSourceFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) GitLabSourceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends GitLabSourceSpecFluentImpl<GitLabSourceFluentImpl.SpecNested<N>> implements GitLabSourceFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(GitLabSourceSpec item) {
      this.builder = new GitLabSourceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new GitLabSourceSpecBuilder(this);
    }
    GitLabSourceSpecBuilder builder;
    public N and() {
      return (N) GitLabSourceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends GitLabSourceStatusFluentImpl<GitLabSourceFluentImpl.StatusNested<N>> implements GitLabSourceFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(GitLabSourceStatus item) {
      this.builder = new GitLabSourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new GitLabSourceStatusBuilder(this);
    }
    GitLabSourceStatusBuilder builder;
    public N and() {
      return (N) GitLabSourceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
